aboutsummaryrefslogtreecommitdiffstats
path: root/tools/perf/util/record.c
diff options
context:
space:
mode:
authorArnaldo Carvalho de Melo <acme@redhat.com>2020-04-29 15:57:01 -0300
committerArnaldo Carvalho de Melo <acme@redhat.com>2020-05-05 16:35:30 -0300
commit6ec17b4e2592a328b08e888d107e31cfd69d6abb (patch)
tree0862a0029e626a95eb4e64403b017d2cc8591aea /tools/perf/util/record.c
parentperf evsel: Rename perf_evsel__exit() to evsel__exit() (diff)
downloadlinux-dev-6ec17b4e2592a328b08e888d107e31cfd69d6abb.tar.xz
linux-dev-6ec17b4e2592a328b08e888d107e31cfd69d6abb.zip
perf evsel: Rename perf_evsel__config*() to evsel__config*()
As they are all 'struct evsel' methods, not part of tools/lib/perf/, aka libperf, to whom the perf_ prefix belongs. Cc: Adrian Hunter <adrian.hunter@intel.com> Cc: Jiri Olsa <jolsa@kernel.org> Cc: Namhyung Kim <namhyung@kernel.org> Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
Diffstat (limited to 'tools/perf/util/record.c')
-rw-r--r--tools/perf/util/record.c9
1 files changed, 4 insertions, 5 deletions
diff --git a/tools/perf/util/record.c b/tools/perf/util/record.c
index 97e2c0cedc12..18ce2cda462a 100644
--- a/tools/perf/util/record.c
+++ b/tools/perf/util/record.c
@@ -15,7 +15,7 @@
#include "../perf-sys.h"
/*
* perf_evsel__config_leader_sampling() uses special rules for leader sampling.
* However, if the leader is an AUX area event, then assume the event to sample
* is the next event.
*/
@@ -34,8 +34,7 @@ static struct evsel *perf_evsel__read_sampler(struct evsel *evsel,
return leader;
}
-static void perf_evsel__config_leader_sampling(struct evsel *evsel,
- struct evlist *evlist)
+static void evsel__config_leader_sampling(struct evsel *evsel, struct evlist *evlist)
{
struct perf_event_attr *attr = &evsel->core.attr;
struct evsel *leader = evsel->leader;
@@ -93,14 +92,14 @@ void perf_evlist__config(struct evlist *evlist, struct record_opts *opts,
use_comm_exec = perf_can_comm_exec();
evlist__for_each_entry(evlist, evsel) {
- perf_evsel__config(evsel, opts, callchain);
+ evsel__config(evsel, opts, callchain);
if (evsel->tracking && use_comm_exec)
evsel->core.attr.comm_exec = 1;
}
/* Configure leader sampling here now that the sample type is known */
evlist__for_each_entry(evlist, evsel)
- perf_evsel__config_leader_sampling(evsel, evlist);
+ evsel__config_leader_sampling(evsel, evlist);
if (opts->full_auxtrace) {
/*
@@ -15,7 +15,7 @@
#include "../perf-sys.h"
/*
- * perf_evsel__config_leader_sampling() uses special rules for leader sampling.
+ * evsel__config_leader_sampling() uses special rules for leader sampling.
* However, if the leader is an AUX area event, then assume the event to sample
* is the next event.